static const char synopsis[] =
    "List and manipulate databases:\n"
    "  syncevolution --print-databases|--create-database|--remove-database [<properties>] [<config> <store>]\n"
    "Show information about configuration(s):\n"
    "  syncevolution --print-servers|--print-configs|--print-peers\n"
    "Show information about a specific configuration:\n"
    "  syncevolution --print-config [--quiet] [--] <config> [main|<store> ...]\n"
    "List sessions:\n"
    "  syncevolution --print-sessions [--quiet] [--] <config>\n"
    "Show information about SyncEvolution:\n"
    "  syncevolution --help|-h|--version\n"
    "Run a synchronization as configured:\n"
    "  syncevolution <config> [<store> ...]\n"
    "Run a synchronization with properties changed just for this run:\n"
    "  syncevolution --run <options for run> [--] <config> [<store> ...]\n"
    "Restore data from the automatic backups:\n"
    "  syncevolution --restore <session directory> --before|--after [--dry-run] [--] <config> <store> ...\n"
    "Create, update or remove a configuration:\n"
    "  syncevolution --configure <options> [--] <config> [<store> ...]\n"
    "  syncevolution --remove|--migrate <options> [--] <config>\n"
    "List items:\n"
    "  syncevolution --print-items [--] [<config> [<store>]]\n"
    "Export item(s):\n"
    "  syncevolution [--delimiter <string>] --export <dir>|<file>|- [--] [<config> [<store> [<luid> ...]]]\n"
    "                                                                --luids <luid> ...\n"
    "Add item(s):\n"
    "  syncevolution [--delimiter <string>|none] --import <dir>|<file>|- [--] [<config> [<store>]]\n"
    "                                                                     --luids <luid> ...\n"
    "Update item(s):\n"
    "  syncevolution --update <dir> [--] <config> <store>\n"
    "  syncevolution [--delimiter <string>|none] --update <file>|- [--] <config> <store> <luid> ...\n"
    "                                                               --luids <luid> ...\n"
    "\n"
    "Remove item(s):\n"
    "  syncevolution --delete-items [--] <config> <store> (<luid> ... | '*')\n"
;
static const char options[] =
    "--sync|-s <mode>|?\n"
    "  Temporarily synchronize the active datastores in that mode. Useful\n"
    "  for a `refresh-from-local` or `refresh-from-remote` sync which\n"
    "  clears all data at one end and copies all items from the other.\n"
    "\n"
    "  **Warning:** `local` is the data accessed via the sync config\n"
    "  directly and `remote` is the data on the peer, regardless\n"
    "  where the data is actually stored physically.\n"
    "\n"
    "--print-servers|--print-configs|--print-peers\n"
    "  Prints the names of all configured peers to stdout. There is no\n"
    "  difference between these options, the are just aliases.\n"
    "\n"
    "--print-servers|--print-configs|--print-peers|-p\n"
    "  Prints the complete configuration for the selected <config>\n"
    "  to stdout, including up-to-date comments for all properties. The\n"
    "  format is the normal .ini format with datastore configurations in\n"
    "  different sections introduced with [<store>] lines. Can be combined\n"
    "  with --sync-property and --datastore-property to modify the configuration\n"
    "  on-the-fly. When one or more datastores are listed after the <config>\n"
    "  name on the command line, then only the configs of those datastores are\n"
    "  printed. `main` selects the main configuration instead of datastore\n"
    "  configurations. Using --quiet suppresses the comments for each property.\n"
    "  When setting a --template, then the reference configuration for\n"
    "  that peer is printed instead of an existing configuration.\n"
    "\n"
    "--print-sessions\n"
    "  Prints information about previous synchronization sessions for the\n"
    "  selected peer or context are printed. This depends on the ``logdir``\n"
    "  property.  The information includes the log directory name (useful for\n"
    "  --restore) and the synchronization report. In combination with\n"
    "  --quiet, only the paths are listed.\n"
    "\n"
    "--configure|-c\n"
    "  Modify the configuration files for the selected peer and/or datastores.\n"
    "\n"
    "  If no such configuration exists, then a new one is created using one\n"
    "  of the template configurations (see --template option). Choosing a\n"
    "  template sets most of the relevant properties for the peer and the\n"
    "  default set of datastores (see above for a list of those). Anything\n"
    "  specific to the user (like username/password) still has to be set\n"
    "  manually.\n"
    "\n"
    "  When creating a new configuration and listing datastores explicitly on the\n"
    "  command line, only those datastores will be set to active in the new\n"
    "  configuration, i.e. `syncevolution -c memotoo addressbook`\n"
    "  followed by `syncevolution memotoo` will only synchronize the\n"
    "  address book. The other datastores are created in a disabled state.\n"
    "  When modifying an existing configuration and datastores are specified,\n"
    "  then the datastore properties of only those datastores are modified.\n"
    "\n"
    "  By default, creating a config requires a template. Datastore names on the\n"
    "  command line must match those in the template. This allows catching\n"
    "  typos in the peer and datastore names. But it also prevents some advanced\n"
    "  use cases. Therefore it is possible to disable these checks in two ways:\n"
    "\n"
    "    - use `--template none` or\n"
    "    - specify all required sync and datastore properties that are normally\n"
    "      in the templates on the command line (syncURL, backend, ...)\n"
    "\n"
    "--run|-r\n"
    "  To prevent accidental sync runs when a configuration change was\n"
    "  intended, but the `--configure` option was not used, `--run` must be\n"
    "  specified explicitly when sync or datastore properties are selected\n"
    "  on the command line and they are meant to be used during a sync\n"
    "  session triggered by the invocation.\n"
    "\n"
    "--migrate\n"
    "  In older SyncEvolution releases a different layout of configuration files\n"
    "  was used. Using --migrate will automatically migrate to the new\n"
    "  layout and rename the <config> into <config>.old to prevent accidental use\n"
    "  of the old configuration. WARNING: old SyncEvolution releases cannot\n"
    "  use the new configuration!\n"
    "\n"
    "  The switch can also be used to migrate a configuration in the current\n"
    "  configuration directory: this preserves all property values, discards\n"
    "  obsolete properties and sets all comments exactly as if the configuration\n"
    "  had been created from scratch. WARNING: custom comments in the\n"
    "  configuration are not preserved.\n"
    "\n"
    "  --migrate implies --configure and can be combined with modifying\n"
    "  properties.\n"
    "\n"
    "--print-items\n"
    "  Shows all existing items using one line per item using\n"
    "  the format \"<luid>[: <short description>]\". Whether the description\n"
    "  is available depends on the backend and the kind of data that it\n"
    "  stores.\n"
    "\n"
    "--export\n"
    "  Writes all items in the datastore or all items whose <luid> is\n"
    "  given into a directory if the --export parameter exists and is a\n"
    "  directory. The <luid> of each item is used as file name. Otherwise it\n"
    "  creates a new file under that name and writes the selected items\n"
    "  separated by the chosen delimiter string. stdout can be selected with\n"
    "  a dash.\n"
    "\n"
    "  The default delimiter (two line breaks) matches a blank line. As a special\n"
    "  case, it also matches a blank line with DOS line ending (line break,\n"
    "  carriage return, line break). This works for vCard 3.0 and iCalendar 2.0,\n"
    "  which never contain blank lines.\n"
    "\n"
    "  When exporting, the default delimiter will always insert two line\n"
    "  breaks regardless whether the items contain DOS line ends. As a\n"
    "  special case, the initial newline of a delimiter is skipped if the\n"
    "  item already ends in a newline.\n"
    "\n"
    "--import\n"
    "  Adds all items found in the directory or input file to the\n"
    "  datastore.  When reading from a directory, each file is treated as one\n"
    "  item. Otherwise the input is split at the chosen delimiter. \"none\" as\n"
    "  delimiter disables splitting of the input.\n"
    "\n"
    "--update\n"
    "  Overwrites the content of existing items. When updating from a\n"
    "  directory, the name of each file is taken as its luid. When updating\n"
    "  from file or stdin, the number of luids given on the command line\n"
    "  must match with the number of items in the input.\n"
    "\n"
    "--delete-items\n"
    "  Removes the specified items from the datastore. Most backends print\n"
    "  some progress information about this, but besides that, no further\n"
    "  output is produced. Trying to remove an item which does not exist\n"
    "  typically leads to an ERROR message, but is not reflected in a\n"
    "  non-zero result of the command line invocation itself because the\n"
    "  situation is not reported as an error by backends (removal of\n"
    "  non-existent items is not an error in SyncML). Use a star * instead\n"
    "  or in addition to listing individual luids to delete all items.\n"
    "\n"
    "--sync-property|-y <property>=<value>|<property>=?|?\n"
    "  Overrides a datastore-independent configuration property for the\n"
    "  current synchronization run or permanently when --configure is used\n"
    "  to update the configuration. Can be used multiple times.  Specifying\n"
    "  an unused property will trigger an error message.\n"
    "\n"
    "--datastore-property|--source-property|-z <property>=<value>|<property>=?|?\n"
    "  Same as --sync-property, but applies to the configuration of all active\n"
    "  datastores. `--sync <mode>` is a shortcut for `--datastore-property sync=<mode>`.\n"
    "\n"
    "--template|-l <peer name>|default|?<device>\n"
    "  Can be used to select from one of the built-in default configurations\n"
    "  for known SyncML peers. Defaults to the <config> name, so --template\n"
    "  only has to be specified when creating multiple different configurations\n"
    "  for the same peer, or when using a template that is named differently\n"
    "  than the peer. `default` is an alias for `memotoo` and can be\n"
    "  used as the starting point for servers which do not have a built-in\n"
    "  template.\n"
    "\n"
    "  A pseudo-random device ID is generated automatically. Therefore setting\n"
    "  the `deviceId` sync property is only necessary when manually recreating a\n"
    "  configuration or when a more descriptive name is desired.\n"
    "\n"
    "  The available templates for different known SyncML servers are listed when\n"
    "  using a single question mark instead of template name. When using the\n"
    "  `?<device>` format, a fuzzy search for a template that might be\n"
    "  suitable for talking to such a device is done. The matching works best\n"
    "  when using `<device> = <Manufacturer> <Model>`. If you don't know the\n"
    "  manufacturer, you can just keep it as empty. The output in this mode\n"
    "  gives the template name followed by a short description and a rating how well\n"
    "  the template matches the device (100% is best).\n"
    "\n"
    "--status|-t\n"
    "  The changes made to local data since the last synchronization are\n"
    "  shown without starting a new one. This can be used to see in advance\n"
    "  whether the local data needs to be synchronized with the server.\n"
    "\n"
    "--quiet|-q\n"
    "  Suppresses most of the normal output during a synchronization. The\n"
    "  log file still contains all the information.\n"
    "\n"
    "--keyring[=<value>]|-k\n"
    "  A legacy option, now the same as setting the global keyring sync property.\n"
    "  When not specifying a value explicitly, \"true\" for \"use some kind of\n"
    "  keyring\" is implied. See \"--sync-property keyring\" for details.\n"
    "\n"
    "--daemon[=yes/no]\n"
    "  By default, the SyncEvolution command line is executed inside the\n"
    "  syncevo-dbus-server process. This ensures that synchronization sessions\n"
    "  started by the command line do not conflict with sessions started\n"
    "  via some other means (GUI, automatically). For debugging purposes\n"
    "  or very special use cases (running a local sync against a server which\n"
    "  executes inside the daemon) it is possible to execute the operation\n"
    "  without the daemon (--daemon=no).\n"
    "\n"
    "--help|-h\n"
    "  Prints usage information.\n"
    "\n"
    "--version\n"
    "  Prints the SyncEvolution version.\n"
    "\n"
    "\n"
    "CONFIGURATION PROPERTIES\n"
    "========================\n"
    "\n"
    "This section lists predefined properties. Backends can add their own\n"
    "properties at runtime if none of the predefined properties are\n"
    "suitable for a certain setting. Those additional properties are not\n"
    "listed here. Use ``--sync/datastore-property ?`` to get an up-to-date\n"
    "list.\n"
    "\n"
    "The predefined properties may also be interpreted slightly differently\n"
    "by each backend and sync protocol. Sometimes this is documented in the\n"
    "comment for each property, sometimes in the documentation of the\n"
    "backend or sync protocol.\n"
    "\n"
    "Properties are listed together with all recognized aliases (in those\n"
    "cases where a property was renamed at some point), its default value,\n"
    "sharing state (unshared/shared/global). Some properties must be\n"
    "defined, which is marked with the word `required`.\n"
    "\n"
    "Sync properties\n"
    "---------------\n"
    "<< see \"syncevolution --sync-property ?\" >>\n"
    "\n"
    "Datastore properties\n"
    "--------------------\n"
    "<< see \"syncevolution --datastore-property ?\" >>\n"
;
